@@ -213,7 +213,7 @@ PROGRAM mip_contribution
   !   all CF-netCDF files written as part of this dataset.
 
   print*, 'calling cmor_dataset'
-  error_flag = cmor_dataset_json("Test/common_user_input.json");
+  error_flag = cmor_dataset_json("Test/CMOR_input_example.json");
 
 !  error_flag = cmor_dataset(                                   &
 !       outpath='Test',         &
