@@ -4,7 +4,7 @@ import os
 
 
 pth = os.getcwd()
-common.init_cmor(pth, "common_user_input.json")
+common.init_cmor(pth, "CMOR_input_example.json")
 cmor.load_table(os.path.join(pth, 'Tables', 'CMIP6_6hrLev.json'))
 itim, ilat, ilon = common.read_cmor_time_lat_lon()
 
