@@ -9,7 +9,7 @@ times_bnds = [[11, 134], [2, 125], [5, 128]]
 def path_test():
     cmor.setup(inpath='TestTables', netcdf_file_action=cmor.CMOR_REPLACE)
 
-    cmor.dataset_json("Test/common_user_input.json")
+    cmor.dataset_json("Test/CMOR_input_example.json")
 
 
     table = 'CMIP6_Amon.json'
