@@ -19,6 +19,7 @@ import os
 import sys
 import tempfile
 import cdms2
+import base_CMIP6_CV
 
 
 # ==============================
@@ -30,25 +31,10 @@ def run():
     unittest.main()
 
 
-class TestCase(unittest.TestCase):
-
-    def setUp(self, *args, **kwargs):
-        # ------------------------------------------------------
-        # Copy stdout and stderr file descriptor for cmor output
-        # ------------------------------------------------------
-        self.newstdout = os.dup(1)
-        self.newstderr = os.dup(2)
-        # --------------
-        # Create tmpfile
-        # --------------
-        self.tmpfile = tempfile.mkstemp()
-        os.dup2(self.tmpfile[0], 1)
-        os.dup2(self.tmpfile[0], 2)
-        os.close(self.tmpfile[0])
-
+class TestCase(base_CMIP6_CV.BaseCVsTest):
 
     def testCMIP6(self):
-        cmor.setup(inpath='Tables', netcdf_file_action=cmor.CMOR_REPLACE)
+        cmor.setup(inpath='Tables', netcdf_file_action=cmor.CMOR_REPLACE, logfile=self.tmpfile)
         cmor.dataset_json("Test/common_user_input_hier.json")
 
         cmor.load_table("CMIP6_Omon.json")
@@ -63,11 +49,8 @@ class TestCase(unittest.TestCase):
         for i in range(0, 5):
             # ,time_vals=numpy.array([i,]),time_bnds=numpy.array([i,i+1]))
             cmor.write(ivar, data[i:i])
+        self.delete_files += [cmor.close(ivar, True)]
         cmor.close()
-        os.dup2(self.newstdout, 1)
-        os.dup2(self.newstderr, 2)
-        sys.stdout = os.fdopen(self.newstdout, 'w', 0)
-        sys.stderr = os.fdopen(self.newstderr, 'w', 0)
 
         f = cdms2.open(cmor.get_final_filename() , 'r')
         self.assertEqual(f.coder, "Denis Nadeau")
@@ -77,8 +60,5 @@ class TestCase(unittest.TestCase):
         self.assertEqual(f.country, "USA")
         f.close()
 
-       
-
-
 if __name__ == '__main__':
     run()
