@@ -4,7 +4,7 @@ import cmor
 def multi_call_test():
     cmor.setup(inpath='Tables', netcdf_file_action=cmor.CMOR_REPLACE)
 
-    cmor.dataset_json("Test/common_user_input.json")
+    cmor.dataset_json("Test/CMOR_input_example.json")
     table = 'CMIP6_Amon.json'
     cmor.load_table(table)
     axes = [{'table_entry': 'time',
