@@ -6,7 +6,7 @@ def cmor_initialisation():
     cmor.setup(inpath='Tables',
                netcdf_file_action=cmor.CMOR_REPLACE_3,
                create_subdirectories=0)
-    cmor.dataset_json("Test/common_user_input.json")
+    cmor.dataset_json("Test/CMOR_input_example.json")
 
 
 def setup_data():
