@@ -12,7 +12,7 @@ def prep(mode):
         inpath='Tables',
         netcdf_file_action=mode)
 
-    error_flag = cmor.dataset_json("Test/common_user_input.json")
+    error_flag = cmor.dataset_json("Test/CMOR_input_example.json")
 
 
 def prep_var(var, units):
