@@ -12,6 +12,10 @@
 
 extern void cmor_md5( FILE * inputfile, unsigned char checksum[16] );
 
+extern void cmor_set_terminate_signal_to_sigint();
+extern void cmor_set_terminate_signal_to_sigterm();
+extern void cmor_set_terminate_signal( int );
+extern int cmor_get_terminate_signal();
 extern void cmor_is_setup( void );
 extern void cmor_add_traceback( char *name );
 extern void cmor_pop_traceback( void );
